import { AzureAuthentication, ObjectInputPathsAndPathToObject } from "@octopusdeploy/step-inputs";
import { DeploymentTargetInputComponent } from "../InputComponents";
import { radioButtons } from "../RadioButtons";
import { note } from "../Note";
import { account } from "../Account";
import { link } from "../Link";

export function azureAuthentication({ input }: AzureAuthenticationProps): DeploymentTargetInputComponent[] {
    const content: DeploymentTargetInputComponent[] = [
        radioButtons({
            input: input.credentials,
            label: "Credentials",
            helpText: "Select the Azure authentication method.",
            options: [
                {
                    label: "Use a Service Principal Account",
                    newValue: {
                        type: "account",
                    },
                },
                {
                    label: "Use an OpenID Connect Account",
                    newValue: {
                        type: "oidcAccount",
                    },
                },
            ],
            note: note`Azure Service Principals support both Credential and Open Id Connect based authentication. For more information on Oidc accounts in Octopus see ${link(
                {
                    title: "OpenID Connect Accounts",
                    href: "OpenIdConnectClientConfiguration",
                }
            )}.`,
        }),
    ];

    if (input.credentials.type === "account") {
        content.push(
            account({
                input: input.credentials.account,
                label: "Azure Account",
                helpText: "The account to authenticate with.",
            })
        );
    }

    if (input.credentials.type === "oidcAccount") {
        content.push(
            account({
                input: input.credentials.account,
                label: "Azure OIDC Account",
                helpText: "The OpenID Connect account to authenticate with.",
            })
        );
    }

    return content;
}

export interface AzureAuthenticationProps {
    input: ObjectInputPathsAndPathToObject<AzureAuthentication>;
}
