import type { InitialInputs } from "./InitialInputs";
import type { ObjectInputPaths } from "@octopusdeploy/step-inputs";
import type { FormContent } from "./FormContent";
import type { StepInputComponent } from "./InputComponents";
import type { ConfigurationExport } from "./ConfigurationExport";
import { NoteExpression } from "./Note";

export interface StepUI<StepInputs> {
    editInputsForm: EditStepInputsForm<StepInputs>;
    createInitialInputs: () => InitialInputs<StepInputs>;
    exportConfiguration?: ConfigurationExport<StepInputs>[];
    configuration?: StepUIConfiguration;
}

export type StepUIConfiguration = StepUIContainerConfiguration & {
    /**
     * Whether the "Execution timeout" option is shown for this step.
     * Defaults to `true`.
     */
    canUseExecutionTimeouts?: boolean;

    /**
     * Whether the top-level UI components are rendered under the `Configuration` expander.
     * Defaults to `true`.
     */
    useConfigurationUISection?: boolean;
};

type StepUIContainerConfiguration =
    | {
          /**
           * Whether the "Run in Execution Container" option is shown for this step.
           * Defaults to `true`.
           */
          canRunInExecutionContainer?: false;
      }
    | {
          /**
           * Whether the "Run in Execution Container" option is shown for this step.
           * Defaults to `true`.
           */
          canRunInExecutionContainer: true;

          /**
           * An optional array of `NoteExpression`s for rendering information about the recommended container image to use for this step.
           * This should only be set if `canRunInExecutionContainer` is set to `true`. Otherwise, it is ignored.
           * Defaults to `undefined`.
           */
          containerImageRecommendation?: NoteExpression[];
      };

export const defaultStepUIConfiguration: StepUIConfiguration = {
    canRunInExecutionContainer: true,
    canUseExecutionTimeouts: true,
    useConfigurationUISection: true,
};

export type EditStepInputsForm<StepInputs> = (inputPaths: ObjectInputPaths<StepInputs>) => FormContent<StepInputComponent>[];
